@@ -28,10 +28,20 @@ class EdxNameAffirmationConfig(AppConfig):
                         'receiver_func_name': 'idv_attempt_handler',
                         'signal_path': 'lms.djangoapps.verify_student.signals.idv_update_signal',
                     },
+                    {
+                        'receiver_func_name': 'idv_delete_handler',
+                        'signal_path': 'django.db.models.signals.post_delete',
+                        'sender_path': 'lms.djangoapps.verify_student.models.SoftwareSecurePhotoVerification',
+                    },
                     {
                         'receiver_func_name': 'proctoring_attempt_handler',
                         'signal_path': 'edx_proctoring.signals.exam_attempt_status_signal',
-                    }
+                    },
+                    {
+                        'receiver_func_name': 'proctoring_delete_handler',
+                        'signal_path': 'django.db.models.signals.post_delete',
+                        'sender_path': 'edx_proctoring.models.ProctoredExamStudentAttempt',
+                    },
                 ],
             }
         }
