@@ -4,4 +4,4 @@ Name Affirmation signals
 
 from django.dispatch import Signal
 
-VERIFIED_NAME_APPROVED = Signal(providing_args=['user_id', 'profile_name'])
+VERIFIED_NAME_APPROVED = Signal()
